@@ -1,5 +1,6 @@
 import os
 import re
+import json
 
 
 
@@ -191,4 +192,16 @@ def list2dict(li):
     return di
 
 
+def _stock_dict(filename="info.json"):
+    di = dict()
+    json_dict = json.load(open(filename))
+    for key in json_dict:
+        elems = json_dict[key]
+        for code in elems:
+            di[code] = code
+            di[elems[code]["stock_name"]] = code
+    return di
+
+
+
 
